# coding=utf-8
# --------------------------------------------------------------------------
# Code generated by Microsoft (R) AutoRest Code Generator.
# Changes may cause incorrect behavior and will be lost if the code is
# regenerated.
# --------------------------------------------------------------------------

from msrest.serialization import Model


class MeterEdit(Model):
    """MeterEdit.

    :param meter_code: The meter code <span
     class='property-internal'>Required</span> <span
     class='property-internal'>Must be between 0 and 32 characters</span>
    :type meter_code: str
    :param meter_info: The meter info <span
     class='property-internal'>Required</span> <span
     class='property-internal'>Must be between 0 and 50 characters</span>
    :type meter_info: str
    :param place_id: The identifier for the place the meter is assigned to
     <span class='property-internal'>Topmost (Place)</span> <span
     class='property-internal'>Required</span>
    :type place_id: int
    :param commodity_id: The commodity identifier that the meter is assigned
     to.
     If different from original commodity id, then a commodity change will be
     attempted. <span class='property-internal'>Required</span>
    :type commodity_id: int
    :param address:
    :type address: ~energycap.sdk.models.AddressChild
    :param bill_entry_note: The bill entry note <span
     class='property-internal'>Must be between 0 and 64 characters</span> <span
     class='property-internal'>Required (defined)</span>
    :type bill_entry_note: str
    :param include_in_energy_star: Indicates if the meter should be included
     in ENERGY STAR <span class='property-internal'>Required</span>
    :type include_in_energy_star: bool
    :param primary_use_id: The identifier for the meter's primary use <span
     class='property-internal'>Required (defined)</span>
    :type primary_use_id: int
    :param meter_time_zone_id: The identifier for the meter's time zone. <span
     class='property-internal'>Required</span>
    :type meter_time_zone_id: int
    :param active: Is this meter active? <span
     class='property-internal'>Required</span>
    :type active: bool
    :param properties: An array of meter properties <span
     class='property-internal'>Required (defined)</span>
    :type properties: dict[str, str]
    :param use_unit_id: The use unit ID is the reporting unit for use for this
     meter.
     It is used to determine initial bill format for this meter. <span
     class='property-internal'>Required (defined)</span>
    :type use_unit_id: int
    :param demand_unit_id: The demand unit ID is the reporting unit for demand
     for this meter.
     It is used to determine initial bill format for this meter. <span
     class='property-internal'>Required (defined)</span>
    :type demand_unit_id: int
    """

    _validation = {
        'meter_code': {'required': True, 'max_length': 32, 'min_length': 0},
        'meter_info': {'required': True, 'max_length': 50, 'min_length': 0},
        'place_id': {'required': True},
        'commodity_id': {'required': True},
        'address': {'required': True},
        'bill_entry_note': {'required': True, 'max_length': 64, 'min_length': 0},
        'include_in_energy_star': {'required': True},
        'primary_use_id': {'required': True},
        'meter_time_zone_id': {'required': True},
        'active': {'required': True},
        'properties': {'required': True},
    }

    _attribute_map = {
        'meter_code': {'key': 'meterCode', 'type': 'str'},
        'meter_info': {'key': 'meterInfo', 'type': 'str'},
        'place_id': {'key': 'placeId', 'type': 'int'},
        'commodity_id': {'key': 'commodityId', 'type': 'int'},
        'address': {'key': 'address', 'type': 'AddressChild'},
        'bill_entry_note': {'key': 'billEntryNote', 'type': 'str'},
        'include_in_energy_star': {'key': 'includeInEnergyStar', 'type': 'bool'},
        'primary_use_id': {'key': 'primaryUseId', 'type': 'int'},
        'meter_time_zone_id': {'key': 'meterTimeZoneId', 'type': 'int'},
        'active': {'key': 'active', 'type': 'bool'},
        'properties': {'key': 'properties', 'type': '{str}'},
        'use_unit_id': {'key': 'useUnitId', 'type': 'int'},
        'demand_unit_id': {'key': 'demandUnitId', 'type': 'int'},
    }

    def __init__(self, meter_code, meter_info, place_id, commodity_id, address, bill_entry_note, include_in_energy_star, primary_use_id, meter_time_zone_id, active, properties, use_unit_id=None, demand_unit_id=None):
        super(MeterEdit, self).__init__()
        self.meter_code = meter_code
        self.meter_info = meter_info
        self.place_id = place_id
        self.commodity_id = commodity_id
        self.address = address
        self.bill_entry_note = bill_entry_note
        self.include_in_energy_star = include_in_energy_star
        self.primary_use_id = primary_use_id
        self.meter_time_zone_id = meter_time_zone_id
        self.active = active
        self.properties = properties
        self.use_unit_id = use_unit_id
        self.demand_unit_id = demand_unit_id



# coding=utf-8
# --------------------------------------------------------------------------
# Code generated by Microsoft (R) AutoRest Code Generator.
# Changes may cause incorrect behavior and will be lost if the code is
# regenerated.
# --------------------------------------------------------------------------

from msrest.serialization import Model


class AccountMeterRequest(Model):
    """AccountMeterRequest.

    :param account_id: The account identifier for this account meter <span
     class='property-internal'>Required</span> <span
     class='property-internal'>Topmost (Account)</span>
    :type account_id: int
    :param meter_id: The meter identifier for this account meter <span
     class='property-internal'>Required</span> <span
     class='property-internal'>Topmost (Meter)</span>
    :type meter_id: int
    :param begin_date: The beginning date and time for this account meter
     relationship
     Defaults to 1899-01-01
    :type begin_date: datetime
    :param end_date: The ending date and time for this account meter
     relationship
     Defaults to 3000-01-01
    :type end_date: datetime
    :param general_ledger_id: The identifier for the general ledger assigned
     to this account meter
    :type general_ledger_id: int
    :param vendor_type_id: The identifier for the vendor type. Vendors may
     assume different types on different account meters
    :type vendor_type_id: int
    :param deregulated: Indicates if the account meter is deregulated
    :type deregulated: bool
    :param template_id: Indicates if the account meter template
     Optional.
     If not passed the template will be defaulted using the meter's assigned
     use and demand units
     First try and match template by commodityId, useUnitId, demandUnitId
     If no match try commodityId, useUnitId
     If no match select the first use only template that matches on commodity
     If none is found no template will be assigned
    :type template_id: int
    :param rate_id: Indicates if the account meter rate <span
     class='property-internal'>Required</span>
    :type rate_id: int
    """

    _validation = {
        'account_id': {'required': True},
        'meter_id': {'required': True},
        'rate_id': {'required': True},
    }

    _attribute_map = {
        'account_id': {'key': 'accountId', 'type': 'int'},
        'meter_id': {'key': 'meterId', 'type': 'int'},
        'begin_date': {'key': 'beginDate', 'type': 'iso-8601'},
        'end_date': {'key': 'endDate', 'type': 'iso-8601'},
        'general_ledger_id': {'key': 'generalLedgerId', 'type': 'int'},
        'vendor_type_id': {'key': 'vendorTypeId', 'type': 'int'},
        'deregulated': {'key': 'deregulated', 'type': 'bool'},
        'template_id': {'key': 'templateId', 'type': 'int'},
        'rate_id': {'key': 'rateId', 'type': 'int'},
    }

    def __init__(self, account_id, meter_id, rate_id, begin_date=None, end_date=None, general_ledger_id=None, vendor_type_id=None, deregulated=None, template_id=None):
        super(AccountMeterRequest, self).__init__()
        self.account_id = account_id
        self.meter_id = meter_id
        self.begin_date = begin_date
        self.end_date = end_date
        self.general_ledger_id = general_ledger_id
        self.vendor_type_id = vendor_type_id
        self.deregulated = deregulated
        self.template_id = template_id
        self.rate_id = rate_id



# coding=utf-8
# --------------------------------------------------------------------------
# Code generated by Microsoft (R) AutoRest Code Generator.
# Changes may cause incorrect behavior and will be lost if the code is
# regenerated.
# --------------------------------------------------------------------------

from msrest.serialization import Model


class MissingBillWidget(Model):
    """MissingBillWidget.

    :param gap_begin_date: The begin date of the gap in billing data
    :type gap_begin_date: datetime
    :param gap_end_date: The end date of the gap in billing data
    :type gap_end_date: datetime
    :param gap_days: The number of days in the gap in billing data
    :type gap_days: int
    :param account_id: The account that is missing billing data
    :type account_id: int
    :param account_info: The account that is missing billing data
    :type account_info: str
    :param meter_info: The meter that is missing billing data
    :type meter_info: str
    """

    _attribute_map = {
        'gap_begin_date': {'key': 'gapBeginDate', 'type': 'iso-8601'},
        'gap_end_date': {'key': 'gapEndDate', 'type': 'iso-8601'},
        'gap_days': {'key': 'gapDays', 'type': 'int'},
        'account_id': {'key': 'accountId', 'type': 'int'},
        'account_info': {'key': 'accountInfo', 'type': 'str'},
        'meter_info': {'key': 'meterInfo', 'type': 'str'},
    }

    def __init__(self, gap_begin_date=None, gap_end_date=None, gap_days=None, account_id=None, account_info=None, meter_info=None):
        super(MissingBillWidget, self).__init__()
        self.gap_begin_date = gap_begin_date
        self.gap_end_date = gap_end_date
        self.gap_days = gap_days
        self.account_id = account_id
        self.account_info = account_info
        self.meter_info = meter_info
